#
# spec file for package gpac
#
# Copyright (c) 2024 Packman Team <packman@links2linux.de>
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define sover   12
Name:           gpac
Version:        2.4.0
Release:        150600.1.pm.3
Summary:        A multimedia framework covering MPEG-4, VRML/X3D and SVG
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://gpac.io
Source:         https://github.com/gpac/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
#PATCH-FIX-UPSTREAM i@marguerite.su - fix SVGGen ldflags
Patch2:         gpac-0.7.1-SVGGen_abuild.patch
#PATCH-FIX-UPSTREAM wengxuetian@gmail.com - fix E: 64bit-portability-issue
Patch3:         gpac-1.0.0-64bit-portability.patch
Patch12:        gpac.ssl.patch
#PATCH-FIX-OPENSUSE gpac-rpath.patch aloisio@gmx.com - fix rpath error
Patch13:        gpac-rpath.patch
%if 0%{?suse_version} > 1500
#PATCH-FIX-OPENSUSE gpac.a52dec.patch manfred.h@gmx.net - add missing parameter to a52_init()
Patch15:        gpac.a52dec.patch
%endif
BuildRequires:  Mesa-devel
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxvidcore-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(faad2)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(liba52)
BuildRequires:  pkgconfig(libavcodec) < 60
BuildRequires:  pkgconfig(libavformat) < 60
BuildRequires:  pkgconfig(libswscale) < 7
BuildRequires:  pkgconfig(libavdevice) < 60
BuildRequires:  pkgconfig(libavutil) < 58
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%description
GPAC is a multimedia framework for MPEG-4, VRML/X3D and SVG/SMIL.

GPAC is built upon an implementation of the MPEG-4 Systems standard
(ISO/IEC 14496-1) developed from scratch in C.

The main development goal is to provide a clean (a.k.a. readable by
as many people as possible), small and flexible alternative to the
MPEG-4 Systems reference software (known as IM1 and distributed in
ISO/IEC 14496-5).

The second development goal is to achieve integration of recent
multimedia standards (SVG/SMIL, VRML, X3D, SWF, etc) into a single
framework. This stage is still under drafting but GPAC already
supports most of VRML97, some X3D as well as very simple SVG.

GPAC already features 2D and 3D multimedia playback, MPEG-4 Systems
encoders/multiplexers and publishing tools for content distribution.

GPAC is licensed under the GNU Lesser General Public License.

The current GPAC release (0.4.5) already covers a very large part of
the MPEG-4 standard, and features what can probably be seen as the
most advanced and robust 2D MPEG-4 Player available worldwide, as
well as a decent 3D MPEG-4/VRML player.

%package -n libgpac%{sover}
Summary:        Shared libraries for gpac
Group:          System/Libraries

%description -n libgpac%{sover}
Shared libraries for package gpac.

%package -n libgpac-devel
Summary:        Development files for gpac
Group:          Development/Languages/C and C++
Requires:       libgpac%{sover} = %{version}
# old name
Provides:       gpac-devel = %{version}
Obsoletes:      gpac-devel < %{version}

%description -n libgpac-devel
Development files for gpac.

%prep
%autosetup -p1

%build
# configure the beast
./configure \
   --prefix="%{_prefix}" \
   --libdir="%{_lib}" \
   --mandir="%{_mandir}" \
   --use-a52=system \
   --extra-cflags="%{optflags} -D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_LARGEFILE_SOURCE=1 -DXP_UNIX -fPIC"

%make_build all
%make_build -C applications/generators/MPEG4
%make_build -C applications/generators/SVG
%make_build -C applications/generators/X3D

# create dev-docs
pushd share/doc
    doxygen -u
    doxygen
popd

%install
%make_install

# header files
make install-lib \
    DESTDIR=%{buildroot}

# generated sggen binaries
for i in MPEG4 SVG X3D; do
    install -m 755 applications/generators/$i/${i}Gen \
    	%{buildroot}%{_bindir}
done

# install manpages
mkdir -pv %{buildroot}%{_mandir}/man1
install -m0644 share/doc/man/* -t %{buildroot}%{_mandir}/man1

# install html documentation
mkdir -pv %{buildroot}%{_defaultdocdir}/libgpac-devel
cp -a share/doc/html-libgpac %{buildroot}%{_defaultdocdir}/libgpac-devel/

# fix categories
%suse_update_desktop_file -r %{name} 'AudioVideo;Player;'

# static lib
rm -rf %{buildroot}%{_libdir}/*.a

# Windows includes
rm -rf %{buildroot}%{_includedir}/win32 %{buildroot}%{_includedir}/wince

%fdupes %{buildroot}

%post -n libgpac%{sover} -p /sbin/ldconfig

%postun -n libgpac%{sover} -p /sbin/ldconfig

%files
%doc Changelog README.md
%license COPYING
%{_bindir}/MP4Box
%{_bindir}/MPEG4Gen
%{_bindir}/X3DGen
%{_bindir}/SVGGen
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_libdir}/%{name}
%{_mandir}/man1/gpac.1%{?ext_man}
%{_mandir}/man1/gpac-filters.1%{?ext_man}
%{_mandir}/man1/mp4box.1%{?ext_man}

%files -n libgpac%{sover}
%{_libdir}/libgpac.so.%{sover}
%{_libdir}/libgpac.so.%{sover}.*

%files -n libgpac-devel
%doc share/doc/CODING_STYLE share/doc/ipmpx_syntax.bt
%doc share/doc/html-libgpac
%{_includedir}/%{name}/
%{_libdir}/libgpac.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed Apr 17 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4
  Emscripten|WebAssembly(WASM) support:
  * Session can run in worker or in main browser loop
  * Automatic disable of ffdec and ffenc threads when not
    running in worker
  * Use fetch() api for downloader
  * Support for WebCodecs
  * Support for getUserMedia and canvas readable streams
  * gpac.html demo page
  Media Formats:
  * Fixes in text subtitle converters
  * Improved DolbyVision muxing from mkv
  * Dasher support for inputs with multiple stsd entries
  * Allow multiplexed representations for LL-HLS
  * Improved eac3 support
  * QT cmov support (reading and writing)
  * QT lpcm support
  * Improved chaptering support
  * Improved timecode inspection
  * Support for big-endian PCM formats
  * Support for uncv (raw video in mp4 and heif)
  * Support for forced subtitles
  * Support for HEVC bitstreams merging in dash (for multi-res
    tile adaptation)
  Filters:
  * Async HTTP request in all filters
  * JS/Python/NodeJS bindings for httpout server
  * Fixed CORS and mime types in httpout for wasm and
    sharedArrayuffer support
  * Allow compilation without threads
  * Allow compilation without network
  * Fixed GF_FileIO for async read and write modes
  * Added seeking in mp4dmx in mem mode
  * vout updated to use VBO (required for gles2)
  * libcaca video output support
  * Allow ffdmx to work as demux filter on gpac input file pids
  * GHI format for pre-indexing DASH/HLS session for JIT
    packaging/encryption/transcode
  * Zero-copy for mp4dmx and fragmented mp4mx
  * Various speed optimizations (filter session, isomedia lib,
    disk io, xml)
  * Allow running the session without mutexes
  * Closed Caption decoding filter (CEA708)
  * MPEG-H decoder using IIS mpeghdec
  * Templating for property assignment
  * Conditional filter replacement to identify based on codecID
  * Per-filter logging
  MP4Box:
  * Add track reordering option
  Misc:
  * Migrated doc from github's wiki to wiki.gpac.io
  * FFMPEG 7 support
  * Added features for configure (vout, aout, fonts, doc, evg)
  * Allow specifying network interface by name or IP (instead of
    IP only)
  * UDP/TCP filtering and recording to / playback from pcap,
    pcapng and GPAC gpc files
  * Added Nix and Docker build files
  * many bug fixes, improvements and security patches
- Refresh gpac-rpath.patch
- Drop gpac-doxygen_195.patch (merged upstream)
* Wed Oct 18 2023 Manfred Hollstein <manfred.h@gmx.net>
- Add gpac.a52dec.patch when building for Tumbleweed or Slowroll
* Mon Apr 24 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.2.1
  Security:
  * Backport of various CVE fixes
* Mon Dec 19 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.2.0
  Media Formats:
  * 2-pass encoding for FFmpeg codecs other than libx264
  * Conversion filters for VTT, TXG3 and TTML
  * SubstationAlpha subtitle import (basic)
  * DVB subpictures in M2TS mux and demux
  * FFMPEG (mostly for Matroska) subtitle import and export
    (SRT/SSA to TX3G, TX3G to SRT, WebVTT and DVB subpictures)
  * EC3+Atmos signaling support
  * ALAC support
  * Improved DolbyVision muxing
  Media player:
  * subtitle delay and position adjustment
  * audio delay adjustment
  MP4Box:
  * allow numbers and media types as identifiers for track
    actions
  * dlba option to update atmos+ec3 signaling
  Filters:
  * UTC-based range extraction in reframer
  * Thumbnail generator filter
  * Added unframer filter
  * FFMPEG bitstream filters support
  * initseg support in mp4dmx filter
  * Access to GPU textures of decoders in Python and JSF
    bindings (glpush filter for tests)
  * Chapters editing and original timestamp dispatch in reformer
    range extraction
  * dual in-band and out-of-band parameter set support in dasher
  * non-blocking IO for RTSP and HTTP servers/clients
  * RTSP over HTTP in rtsp server
  * Source-Specific multicast for udp and rtp inputs
  * User Authentication for HTTP and RTSP servers
  * TLS support for RTSP client and server
  * Per-filter buffering options
  Encryption:
  * ClearKey support in dasher and decryption
  Misc:
  * QT metadata tags in MP4Box and qt muxer
  * support for some packet properties in URL templates
  DEPRECATED:
  * Removed GF_Terminal API
  * Removed MP4Client, merged old behaviour in gpac -mp4c
  * Removed filemode option from dash demure
- Switch build from sdl to sdl2
- Raise sover to 12
- Add gpac-rpath.patch and gpac-doxygen_195.patch
- Drop gpac-rpmlintrc
* Sat Mar  5 2022 Bjørn Lie <zaitor@opensuse.org>
- No longer force the package to build against ffmpeg-3.x.
  Support for ffmpeg-4.x.x have been around for several versions.
* Thu Feb 24 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.0
  Adaptive Streaming:
  * Low Latency HLS (LL-HLS, generation and playback)
  * Custom forwarding modes of DASH reader, allowing for example
    to encrypt/decrypt a live DASH/HLS session
  * DASHing now possible using inband cues (generated by flist,
    dashin or dasher filters)
  * Cue-generation only mode for dasher
  * HLS/DASH signaling of intra-only representations
  * playback improvements for SRD (HEVC tiling and independent
    streams)
  * CMAF-compatible signaling
  * PPS injection for inband parameter set modes
  * Improved SmoothStreaming support
  * DASH period continuity support (from playlists or reframer)
  * DASH MPD Chaining support
  * Text segments in native format (WebVTT, TTML) in dasher
  * User tags injection for HLS master and variant playlists
  Image File Format (HEIF):
  * Grid creation and other derived images
  * Encryption
  * Time range in -add-image
  * Item to sample data reference (no copy)
  * Item to item data reference (no copy)
  * Generic auxiliary image tagging
  * Image replacement in HEIF collection
  * AV1 (AVIF) and VVC support
  MP4Box:
  * In-place editing (no file remultiplexing)
  * Improved splitting, including sample-accurate split
  * ISOBMFF edit lists modification through :edits and -edits
    options
  * Track extraction from non ISOBMFF sources in MP4Box
  * Most import options can now be applied on an existing ISOBMF
    file or track
  * Multiple filter chains per source in -dash or -add modes
  * Chunk interleaving dumper
  Filters:
  * Simplified gpac command line (backward compatible syntax)
    avoiding links directives for common cases
  * Added avmix, a playlist-based audio video mixer/compositor
    with GPU or software rendering
  * Python bindings for filter session
  * NodeJS bindings for filter session
  * Custom HAS adaptation algorithms (JS, Python and NodeJS)
  * Custom Remotery callbacks (JS, Python and NodeJS)
  * Added avgen, a simple counter generation
  * Splicing support in playlists: raw and compressed domain,
    vod and live splicing
  * Tile splitting now available as a filter
  * Added restamp, a stream timestamp rewriter filter
  * Added bssplit and bsagg, compressed bitstream splitter and
    aggregator filters
  * Aspect ratio support in rescaler (ffsws)
  * Raw (uncompressed) modes for flist and reframer
  * Flip and rotate in vout
  * Simple UI for vout to test seeking and speed modes
  * Improved color space support in rendering (OpenGL only)
  * Improved round-trip audio decode
  * Improved audio resampler
  * Added back old arch compositor features (TEMI support, HEVC
    tiling JS monitoring, MPEG-4 SegmentDescriptor)
  * Reading back frame interface data (GPU, decoder mem) in JS
    or Python sink filters
  * Memory storage in httpout server file sink
  * FileIO wrapper available in QJS, Python and NodeJS
  Protocols:
  * HTTP/2 (client and server) through nghttp2
  * ROUTE multiplexer and low-latency ROUTE (mux and demux)
  Media Formats:
  * Improved MPEG-H audio mux/demux/dashing
  * VVC parsing, inspecting, mux/demux (ISOBMFF, M2TS), RTP,
    DASH and encryption
  * VUI color info rewrite for AVC, HEVC and VVC (mp4box and
    bsrw filter)
  * Dolby TrueHD
  * DolbyVision muxing
  * Improved multichannel AAC (>=8) support
  * Improved raw video in ISOBMFF support
  * Bitstream dumping for inspect analyze mode
  * Improved TTML support: metrics, image embedding (IMSC1),
    TTML sample merging while exporting, subtitle zero in TTML
  * YouTube VR meta-data
  * yuv4mpeg format read/write
  * Extended NHML syntax for properties, reconfiguration,
    subsamples and sample auxiliary data
  Encryption:
  * Multi-key per sample encryption
  * HLS full segment encryption and decryption
  * Per-segment or per-period key roll
  * Master/leaf key schemes
  Misc:
  * Improved HTTP rate limiter and chunk-transfer rate estimator
  * Cleanup of mod-dirs and js-dirs usage, JS filters can now be
    included in the default available filters
  * Support for windows long path
  * Moved to latest QuickJS (2021-03-27)
  * Added QJS-libc modules, support for exec/waitpid/kill and
    Workers on most platforms
  * Support for FFmpeg 4.4 +
  * many bug fixes, improvements and security patches
- Bumped soversion to 11
- Dropped gpac-1.0.1-desktop.patch (no longer necessary)
* Sat Nov 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.1
  * better ttml import
  * better support for MPEGH audio
  * support fur DASH UTCTiming
  * manifest generation from pre-fragmented DASH/HLS mp4
  * speed optimization in isobmf reading (normal and fragmented)
  * improved JS API for the filter session
  * core tools exposed as JS module (file io, bitstream, etc ...)
- Drop gpac-1.0.0-no-pc.patch and gpac-1.0.0-remove_debianism.patch
  (no longer necessary)
- Add gpac-1.0.1-desktop.patch
* Sat Jun 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0
  - Complete rewrite of GPAC streaming core:
    + addition of a filter-based architecture, used by MP4Client
    and MP4Box.
    + moving all decoders and demuxer plugins of MP4Client and
    most of MP4Box import/export code as filters for this new
    architecture,
    + moving DASH/HLS segmenter to a filter
    + moving MP4Client compositor and most of the GF_Terminal
    internals to a filter
    + addition of a new application gpac, whose only purpose is
    to create and run filter chains
    + removal of MP42TS and DashCast applications since these
    functionalities are provided by gpac
    + deprecation of some features (widget management, MSE draft
    implementation for SVG media, UPnP, TEMI player support).
  * Profile system allowing to override through a static file
    default options of all filters and libgpac core
  * Alias system for gpac app to simplify your command lines
  * Enhanced DASHer:
    + Support for HLS and dual HLS / DASH generation
    + Support for any input
    + True low-latency mode for DASH
    + Support for multiple periods
    + Support for other segment formats (raw, mkv, webm
    currently tested)
  * Input and outputs
    + Generic pipe, TCP, UDP, and Unix Domain socket input and
    output
    + RTSP server output
    + HTTP output (client and server), supporting low latency
    DASH access
    + Ad-hoc stream format called GSF to allow serialization to
    file, pipe or socket of a session (for distributed filter
    chains), supporting AES-128 CBC encryption.
  * Raw audio (PCM) and video (RGB, YUV) reframers and exporters
  * HEVC tile spliting and merging filters
  * Compositor is a standalone filter (SVG/BIFS/VRML graphics in
  a filter chain)
  * Image encoding support through libjpg and libpng
  * Full FFMPEG support:
    + Encoding/decoding through FFMPEG libavcodec
    + Multiplexing/demultiplexing through FFMPEG libavformat
    + Device grabbers through FFMPEG libavdevice
    + Raw audio and video filters through FFMPEG libavfilter
  * Support for QuickJS (ES2002) and bindings for:
    + Complete filter API
    + GPAC software rasterizer (EVG)
    + WebGL 1.0 Core
    + XmlHttpRequest and uDOM APIs
    + Storage
  * Inspect and analyze filter
  * MPEG-2 TS splitter
  * Video cropper filter with zero-copy mode
  * Video flip filter
  * Source concatenator filter
  * Simple audio and video output filters
  * Experimental audio and video rewinder filter
  * Encryption
    + On-the-fly encryption and decryption, now available as
    filters
    + Segment-based encryption and decryption
  * ISOBMFF
    + box customization
    + Better QT support, prores parsing and dumping
    + Support for raw media (QT style or ISOBMFF for audio)
    + Simplify HEIF batch conversion through item to track
    mapping
    + Reading from pipes (fragmented or progressive files)
    + Writing to packets rather than files
    + Fast interleaved file creation mode with less storage
    requirements
  * FileIO wrapper for cases where files are not stored in a
    file system known by GPAC
  * Testing and Documentation
    + Live doc generation (man and wiki)
    + Improved coverage
    + Split test suite as dedicated repo
    + Moved all resource to https://wiki.gpac.io
    + Started howto pages on wiki
    + Many bug fixes
- No longer build deprecated DashCast, MP42TS, udptsseg and Osmo4
  applications. Also drop Osmo4 subpackage
- Drop gpac-0.7.1-enable_V4Studio.patch,
  gpac-0.6.1-libpng-version-detection.patch,
  gpac-0.7.1-system-amr.patch,
  gpac-0.5.1-u32-count-redeclaration.patch,
  gpac.wx.patch and gpac-0.8.0-x264-export.patch
- Refresh gpac-0.6.1-64bit-portability.patch as
  gpac-1.0.0-64bit-portability.patch
  and gpac-0.6.1-no-pc.patch as gpac-1.0.0-no-pc.patch,
  gpac.ssl.patch and gpac-rpmlintrc
- Spec cleanup
* Thu Jun 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.0
  General:
  * Many security fixes (static compile and fuzzing through AFL,
    always ongoing).
  * Many bugs fixes
  * Added :ncl option in log levels to disable color logs
  * More tests and coverage
  File Formats:
  * Better support of QTFF / ProRes files
  * Support for AV1
    + import and export
    + source formats: OBUs (Section 5), IVF and AnnexB
    + AV1 in HEIF
  * Support for color (nclc, nclx and ICC profiles) in HEIF and
    ISOBMFF
  * Support for HDR (mdcv, clli) info in HEIF and ISOBMFF
  * Support for alpha in HEIF
  * Support for enforcing pasp presence even for 1:1 ratios
  * HEVC temporal sublayer split in MP4Box
  * Allow meta storage before mdat for meta-only files (heif and
    co)
  * Added option to keep AU delimiter in isobmff samples
  * Support for opus import
  * Support for pixi and ccst in HEIF
  * DolbyVision 'dvcC' and partial 'dvhe' boxes for HDR
  * Support for VP9 import and playback
  * Sample dependency in avc and hevc importers, and track
    thinner for non-refs images
  * Support for audio_roll signaling
  * New audio import mode to control AudioSampleEntry creation
    (v0, v1 ISOBMFF, v1 QTFF)
  * xHE-AAC import with detection of sync samples
  * Added support for MPEG-H 3D audio boxes (no import yet)
  * Handle Vobsub empty SPU packets
  * Added auxv and pict support
  Common Encryption:
  * Fully compliant CENC supporting cenc, cens, cbc1 and cbcs
  * CENC for AV1
  * Improved DASH+CENC support, pssh in MPD
  * ForceClear mode for CENC to skip encryption without sample
    groups
  * Made senc in movie fragments always stored before truns
  * Added default values handling for cbcs and possibility to
    set protection system per track
  * Compatibility with OpenSSL 1.1.x
  Streaming and Adaptive Streaming:
  * Support for ATSC3.0 both US and Korean versions !
  * Support for for live splices (xlink period insertions) in
    DASH client
  * Automatic period continuity in DASH when no codec change
    between periods
  * Added DASH cue-base segmentation (XML based) and -dsap
    option to generate cue files from source
  * Support for BBA-0 and BOLA implementations
  * Write fragment defaults in trex even when not using them
  * Support for simple ssix for keyframe data byterange at the
    start of a segment
  * Moved segment template at AdaptationSet level if only one
    representation
  * Changed default bsmode in dasher if single input file
  * Added init-seg-ext option
  * Added -mvex-after-traks option to MP4Box when dashing for
    CMAF
  * Added segmentation option to insert a tfdt per traf
  * Added -closest mode for DASH segmentation
  * Added -bound option to use audio segmenting method for video
  * Renamed -dash-run-for to -run-for
  * Added '=' in dash templates
  * Improved bandwith estimation when using HTTP 1.1 chunk
    transfer
  * Add option to force moof base offsets
  MP4Box:
  * Added -catpl to concatenate from playlist in MP4Box
  * Added options to set movie timescale at import and dash time
  * Added mpd rip option and top-level box compressor in MP4Box
  * Made -dts skip timing check and added -dtsc for that
  * Made force-cat option more agressive
  * Support for MovieFragmentRandomAccess using -mfra option
  * Added -dtsx to dump timing without offset
  * Added -dnalc opt for nal CRC dump
  * Added chunk extraction up to time until end
  * ISOBMFF single track import now removes references by default
  Decoders:
  * Updated ffmpeg to 4.0.2
  * Moved to openHEVC 3.0 API
  * Added nvdec support (windows, linux) with reuse of decoder
    context for tiled VR
  * Added HEVC support to mediacodec on android
  * AV1 playback through ffmpeg
  * Opus playback through ffmpeg
  3D, VR and 360:
  * Added vrhud for multiviewpoint 360
  * Added forced visibility mode of tiles in VR
  * Added tile visibility debug mode
  * Added forced stereo output for openhevc
  * Disable face nav if mouse grabbed
  * Added simple face tracking vr navigation based on udp
    commands
  * Added PSVR support
  * Added mouse move emulation at window border to force sphere
    rotation when inactive
  * Changed tile visibility algo to sample points in mesh
  Players (Mobile and Desktop):
  * Added about extension
  * Added multiple audio objects in dynamic scene
  * Added addon splicing of main content
  * Added mosaic://v1:.:vN url support
  * Added gaze simulation through mouse and gaze-sphere
    visibility test
  Subtitles:
  * Allow * as argument of -srt|ttxt to dump all possible tracks
    (#925)
  * Improved support for WebVTT import
  * Improved support for WebVTT DASHing/fragmentation
  Misc:
  * OSX install now done through PKG and modify PATH env
    in/etc/paths
  * Added initial PMT version and disc marker to TS muxer
  * Moved dektec output to matrix API, added SDI clipping
  * Added temi periodic toggle and manual toggle in MP42TS
- Bumped soversion to 8
- Refreshed gpac-0.6.1-x264-export.patch as
  gpac-0.8.0-x264-export.patch
- Reworked gpac.ssl.patch (probably pointless, since it applies
  only to OpenSSL 1.0)
- Dropped gpac-0.7.1-install_DashCast.patch (merged upstream)
* Tue Oct  9 2018 aloisio@gmx.com
- Update to version 0.7.1
  * Minor bug fixes from 0.7.0
  version 0.7.0
  Overview of the community activity:
  * ~1550 commits since 0.6.0.
  * Launched a few side projects - cf https://github.com/gpac/.
  * New test public infrastructure.
  General
  * Many security fixes (static compile and fuzzing through AFL,
    always ongoing).
  * Colorized log.
  * Changed default audio volume to 100%% instead of 75%%.
  * Expose more experimental options through the documentation.
  * Improved GLES renderer on mobile platforms.
  * Improvements on AVI dump.
  * Fixed pkg-config Private.libs.
  * SAT>IP playback support.
  Codecs and File Formats
  * Added L-HEVC File Format support (SHVC/MV-HEVC tracks and
    HEVC Tile Tracks).
  * Added MPEG IFF (image File Format) support.
  * Range extension support for AVC and HEVC.
  * SHVC and MV-HEVC importers and playback: moved to final spec
    version (SHM6+).
  Adaptive streaming
  * Support of HLS with fragmented MP4 playback.
  * APIs: gf_mpd_() functions and new segmenter API.
  * Improved alternate groups.
  * More support for PIFF PSEC and Smooth Streaming ( file
    format & playback).
  * DASH client: pluggable algorithms + improvements with
    scalable contents.
  * The counter source from the DASH sequences added to the
    public content.
  * HLS and DASH playback minor fixes.
  * DASH client logs are clearer.
  VR and 360
  * Added support for DASH SRD in 360 for independent videos
    videos (NxM partial spheres) more
  * Added support for DASH SRD in 360 for HEVC tiled videos (NxM
    tiles on one sphere) - checkout tuto
  Mobile
  * Apple VideoToolBox hardware decoding support for OSX and iOS
    for AVC|H264.
  * Android hardware decoding hardware acceleration for AVC|H264
    (HEVC on its way).
  * YUV422 and YUV444 8 and 10 bit support in GLES renderer.
  * Android build is based on Android Studio.
  * Android: new File Manager.
  Subtitles
  * Import of TTML via NHML according to MPEG-4 part 30 improved.
- Refreshed gpac-0.6.1-enable_V4Studio.patch as
  gpac-0.7.1-enable_V4Studio.patch, gpac-0.5.0-SVGGen_abuild.patch
  as gpac-0.7.1-SVGGen_abuild.patch, gpac-0.5.0-system-amr.patch
  as gpac-0.7.1-system-amr.patch, gpac-0.6.1-no-pc.patch,
  gpac-0.6.1-x264-export.patch and gpac.wx.patch
- Added gpac-0.7.1-install_DashCast.patch
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Fri Feb 17 2017 olaf@aepfle.de
- fix some parts of wxWidgets-3_0 build failures
* Fri Apr 29 2016 aloisio@gmx.com
- Update to 0.6.1, see changelog
  https://github.com/gpac/gpac/releases/tag/v0.6.1
  https://github.com/gpac/gpac/releases/tag/v0.6.0
- Reworked patches:
  gpac-0.6.1-64bit-portability.patch
  gpac-0.6.1-enable_V4Studio.patch
  gpac-0.6.1-libpng-version-detection.patch
  gpac-0.6.1-no-pc.patch
  gpac-0.6.1-x264-export.patch
- Switched to ffmpeg 3.0
* Sat Sep 26 2015 olaf@aepfle.de
- Use pkgconfig(mozjs185), also on 11.4
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for some BuildRequires
* Sun Mar  1 2015 aloisio@gmx.com
- update to 0.5.2
  * fixes build problem with ffmpeg 2.5.x
* Sat Feb 28 2015 i@margueirte.su
- update 0.5.1.svn5619
- drop gpac-0.5.1-bufferoverflow.patch
  * upstream fixed
* Wed Nov  5 2014 i@margueirte.su
- update 0.5.1.svn5491
- disable browser plugin support
  * it depends on xulrunner, which is uncompatible during versions
    so we need to use many macros to fix it, hard to maintain
  * gpac is a fundamental package because it's used to build x264
    while fundamental package shouldn't have so complicated depe-
    ndencies
  * that brower plugin wasn't used by anyone
- add patch: gpac-0.5.1-u32-count-redeclaration.patch
  * it declared "u32 count" twice, change the first to countLang
- drop patch:
  * gpac-0.5.0-smjs_call_prop_stub.patch
  * gpac-0.5.0-js_getparent.patch
  * they were used to fix xulrunner, no longer needed
* Mon Jul 14 2014 olaf@aepfle.de
- fix compile of src/utils/xml_parser.c in sle11
* Fri May 30 2014 olaf@aepfle.de
- BuildRequire libopenjpeg only in 12.1 or later
* Sat Mar 22 2014 i@margueirte.su
- update 0.5.0.svn5178
- added patch: gpac-0.5.0-js_getparent.patch
  * fix "too many arguments for JS_GetParent" error after
    forcing USE_FFDEV_18
- added patch: gpac-0.5.0-bufferoverflow.patch
  * fix I: Statement is overflowing a buffer error in OBS.
* Fri Jul 26 2013 i@margueirte.su
- better detect libpng version
- fix no gpac.pc in -devel package
- export functions needed by x264
* Sun Jul 21 2013 i@margueirte.su
- update 0.5.0.svn4668
- revert "wo_application" changes, it fails the whole build
- remove patch: gpac-0.5.0-x264-export.patch, upstreamed
- add libpng15/libpng14 patches.
- use system libamrwb/libamrnb.
* Fri Feb  8 2013 obs@botter.cc
- svn4296 - includes fixes for compilation with Firefox 18
- disable while compiling with xulrunner 17.0.2
  * subpackage Osmo4
  * browser-client
  * MP4client in main package
* Mon Nov  5 2012 i@margueirte.su
- fix sles and < 1140 builds.
* Wed Oct 31 2012 i@margueirte.su
- fix Tumbleweed builds.
- adjust enable_V4Studio.patch.
  * do not use static lib for linking.
* Thu Oct  4 2012 i@marguerite.su
- update to 0.5.0
  * MPEG-DASH and HLS support (players and MP4Box)
  * MPEG-U Widgets and UPnP support in the player
  * Stereo and multiview display support
  * Better AVC and SVC support including OpenSVC decoder integration
  * More live tools: RTP, MPEG-TS, T-DMB support, scene encoders (BIFS and RME/DIMS)
  * iOS and Android support
  * and many other good things
- svn4192 fixes sf#3574796:
  * Osmozilla: change switch_up type from int to long, since xulrunner 15 doesn't support int type directly.
  * change bogus uuid in Osmozilla.
  * fix mozjs15 depreciated JS_ConstructObject to JS_New.
- enable_V4Studio patch
  * upstream masked Osmo4_wx and osmozilla. I enabled them and fix linker errors.
- smjs_call_prop_stub.patch
  * fix openSUSE xulrunner version.
- SVGGen_abuild.patch
  * fix applications/generators/SVG linker errors.
- 64bit-portability.patch
  * fix OBS errors and warnings.
- enable build udptsseg, a HTTP streaming tool.
- spec clean.
  * remove _with_amr. we're already in PMBS.
  * correct BuildRequires package names and remove unneeded Requires.
  * remove dos2unix fixes
  * remove 64bit adjustments. we use upstream options.
  * remove libpng-1.4.0 fix. no longer need.
  * remove SONAME. upstream did that.
  * remove openjpeg fix.
  * remove unneeded configure options.
  * remove < 1140 conditionals.
  * use new ffmpeg. upstream code change.
  * add IDL regeneration for newer xulrunner.
  * enable osmozilla for all openSUSE versions. although few need it.
- TODO: enable hbbtvplayer builds.
* Fri Dec 16 2011 pascal.bleser@opensuse.org
- fix build on recent openSUSE versions, failure was introduced by missing OPENJPEG_VERSION
* Mon Jan 11 2010 toni@links2linux.de
- fixed buildroot usage:
  Error: no modules found in /usr/src/packages/BUILDROOT/gpac-0.4.5-0.pm.5.17.x86_64/usr/lib64/gpac
* Tue Dec  2 2008 toni@links2linux.de
- update to 0.4.5
- added libgpac0 subpackage
- added librsvg2(-devel) to BuildRequires
- install also the *Gen applications
* Wed Sep 24 2008 toni@links2linux.de
- rebuild with new libffmpeg0-devel, libmad-devel, libfaad2-devel,
  libxvidcore-devel packages
- patched for new ffmpeg-API
  (bits_per_sample ==> bits_per_coded_sample, CODEC_ID_MP3LAME ==> CODEC_ID_MP3)
* Fri Dec 21 2007 toni@links2linux.de
- rebuild with new ffmpeg package
* Sun Jul  1 2007 toni@links2linux.de
- use --extra-flags, as CPFLAGS/OPTFLAGS are not recognized in configure
  thx to Richard Sotke <tee@teeforum.com>
* Fri Jun  1 2007 toni@links2linux.de
- merged in 64bit patch/spec-file and corrected BuildRequires
- added rebuild of idl
- should now build on all SuSE-10.x
* Thu May 31 2007 toni@links2linux.de
- update to 0.4.4
* Sat Apr 21 2007 toni@links2linux.de
- update to 0.4.3-cvs20070420
* Fri Mar  9 2007 toni@links2linux.de
- update to 0.4.3-cvs20070309
* Sun Jan 28 2007 toni@links2linux.de
- update to 0.4.3-cvs20070126
* Tue Jan 16 2007 toni@links2linux.de
- update to 0.4.3-cvs20070115
* Wed Dec 13 2006 toni@links2linux.de
- update to 0.4.3-cvs20061213
* Sat Dec  9 2006 toni@links2linux.de
- rebuild with browser-plugin and enabled --enable-amr
* Fri Dec  8 2006 toni@links2linux.de
- initial build 0.4.3-cvs20061114
